# This file is part of Fail2Ban.
#
# Fail2Ban is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Fail2Ban is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Fail2Ban; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

# Author: Cyril Jaquier
# 
# $Revision: 433 $

__author__ = "Cyril Jaquier"
__version__ = "$Revision: 433 $"
__date__ = "$Date: 2006-10-24 21:40:51 +0200 (Tue, 24 Oct 2006) $"
__copyright__ = "Copyright (c) 2004 Cyril Jaquier"
__license__ = "GPL"

import logging
from configreader import ConfigReader
from jailreader import JailReader

# Gets the instance of the logger.
logSys = logging.getLogger("fail2ban.client.config")

class JailsReader(ConfigReader):
	
	def __init__(self):
		ConfigReader.__init__(self)
		self.__jails = list()
	
	def read(self):
		ConfigReader.read(self, "jail")
	
	def getOptions(self):
		opts = []
		self.__opts = ConfigReader.getOptions(self, "Definition", opts)

		for sec in self.sections():
			jail = JailReader(sec)
			jail.read()
			ret = jail.getOptions()
			if ret:
				if jail.isEnabled():
					# We only add enabled jails
					self.__jails.append(jail)
			else:
				logSys.error("Errors in jail '" + sec + "'. Skipping...")
	
	def convert(self):
		stream = list()
		for opt in self.__opts:
			if opt == "":
				stream.append([])
		# Convert jails
		for jail in self.__jails:
			stream.extend(jail.convert())
		# Start jails
		for jail in self.__jails:
			stream.append(["start", jail.getName()])
		
		return stream
		